#
# spec file for package cgns
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libcgns3_2

Name:           cgns
Version:        3.2.1
Release:        6.8
Source0:        cgnslib_%{version}.tar.gz
Source1:        %name-rpmlintrc
Summary:        CFD General Notation System
License:        zlib/libpng
Group:          Development/Libraries/Other
Url:            http://cgns.sourceforge.net/
BuildRequires:  cmake
BuildRequires:  f2c
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  hdf5-devel
BuildRequires:  libxml2-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build


%description
The CFD General Notation System (CGNS) provides a general, portable,
and extensible standard for the storage and retrieval of computational
fluid dynamics (CFD) analysis data. It consists of a collection of
conventions, and free and open software implementing those
conventions. It is self-descriptive, machine-independent,
well-documented, and administered by an international steering
committee. It is also an American Institute of Aeronautics and
Astronautics (AIAA).

The system consists of two parts:
(1) a standard format for recording the data, and
(2) software that reads, writes, and modifies data in that format.

The format is a conceptual entity established by the documentation;
the software is a physical product supplied to enable
developers to access and produce data recorded in that format. 

The CGNS system is designed to facilitate the exchange of data between
sites and applications, and to help stabilize the archiving of
aerodynamic data.  The data are stored in a compact, binary format and
are accessible through a complete and extensible library of functions.
The API (Application Program Interface) is platform independent and
can be easily implemented in C, C++, Fortran and Fortran90
applications.  

%package -n %libname
Summary:        CFD General Notation System library
Group:          System/Libraries
Provides:       lib%{name} = %{version}
Obsoletes:      lib%{name} < %{version}

%description -n %libname
The CFD General Notation System (CGNS) provides a general, portable,
and extensible standard for the storage and retrieval of computational
fluid dynamics (CFD) analysis data. It consists of a collection of
conventions, and free and open software implementing those
conventions. It is self-descriptive, machine-independent,
well-documented, and administered by an international steering
committee. It is also an American Institute of Aeronautics and
Astronautics (AIAA).

The system consists of two parts:
(1) a standard format for recording the data, and
(2) software that reads, writes, and modifies data in that format.

The format is a conceptual entity established by the documentation;
the software is a physical product supplied to enable
developers to access and produce data recorded in that format. 

The CGNS system is designed to facilitate the exchange of data between
sites and applications, and to help stabilize the archiving of
aerodynamic data.  The data are stored in a compact, binary format and
are accessible through a complete and extensible library of functions.
The API (Application Program Interface) is platform independent and
can be easily implemented in C, C++, Fortran and Fortran90
applications.  

%package devel
Summary:        CFD General Notation System library
Group:          Development/Libraries/Other
Requires:       %libname = %{version}
Provides:       lib%{name}-devel = %{version}
Obsoletes:      lib%{name}-devel < %{version}

%description devel
Files required to develop applications using CGNS (CFD General notation system)


%prep
%setup -q -n cgnslib_%version

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
mkdir build
pushd build
cmake .. \
%ifarch x86_64 ppc64 ppc64le aarch64
      -DCGNS_ENABLE_64BIT:BOOL=ON \
%endif
      -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
      -DCGNS_ENABLE_HDF5:BOOL=ON \
      -DCGNS_ENABLE_LEGACY:BOOL=ON \
      -DCGNS_ENABLE_FORTRAN:BOOL=ON \
      -DHDF5_NEED_ZLIB:BOOL=ON \
      -DCMAKE_SKIP_RPATH:BOOL=ON
make %{?_smp_mflags}
popd

%install
pushd build
make install DESTDIR=%{buildroot}

%ifarch x86_64 ppc64 ppc64le aarch64
mv %{buildroot}%{_prefix}/lib %{buildroot}%{_libdir}
%endif
popd

%clean
rm -rf %{buildroot}

%post -n %libname -p /sbin/ldconfig
%postun -n %libname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*

%files -n %libname
%defattr(-,root,root)
%doc changelog license.txt readme.*
%{_libdir}/libcgns.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/adf/
%{_includedir}/adfh/
%{_includedir}/*.h
%{_includedir}/adf/*.h
%{_includedir}/adfh/*.h
%{_includedir}/cgnsBuild.defs
%{_libdir}/libcgns.so
%{_libdir}/libcgns.a

%changelog
* Tue Jul 14 2015 toddrme2178@gmail.com
- Fix building on ppc64le and aarch64
* Thu Jul 17 2014 kilian@lackhove.de
- fixed 64-bit core, HDF5, Legacy and fortran build flags.
* Fri Mar 14 2014 toddrme2178@gmail.com
- Update to 3.2.1
  - fixed problem with IS_FIXED_SIZE macro for cubic elements
  - added check for open file to routines that don't take
    a file number (suggestion from Marc Poinet)
  - added HTMLHelp interface to cmake scripts
  - added AdditionalFamilyName to UserDefinedData
  - fixed compiler complaint about comparison between int and enum
  - added routines to set MPI communicator for parallel I/O
  - updated CMake scripts to work within other scripts (remove conflicts)
  - updates to some cgnstools utility conversion routines
  - fixes and updates to tests and cgnscheck
  - updates to support CG_FILE_ADF2 (2.5 compatibility)
  - fix for point set subregions
- Update to  3.2
  - full integration of parallel I/O using HDF5 with MPI
  - implemented CPEX 0033 and 0034
  - compression (rewriting) of file to remove unused space is no
    longer automatically done, since may interfere with parallel I/O.
    Added cgnscompress program to tools to do this afterwards.
  - removed cgnsversion program from tools since support was getting
    out of hand (N squared problem with versions).
  - added routines to convert to and from AFLR3, FAST, and TetGen
  - implemented cubic elements (CPEX 0036)
  - CGNStools documentation no longer included with source.
    The NASA Glenn website (or local copy) is now used instead.
- Update to 3.1.4-2
  - fixes to cmake scripts for Fortran
  - added check for open file to routines that don't take
    a file number (suggestion from Marc Poinet)
  - CGNStools documentation no longer included with source.
    The NASA Glenn website (or local copy) is now used instead.
  - save window size for cgnsview
  - fix to computing path lists in CMake script
- Update to 3.1.4
  - added some const definitions to library
  - moved unlink of filename when using CG_MODE_WRITE on open to cgio
  - fixed goto for FamilyBCDataset for UserData, .etc
  - added cg_get_cgio_f and cg_root_id_f Fortran routines
  - fixed cmake and configure scripts to allow MPI with HDF5 and
    fixed bugs in those scripts
  - updated CGNSplot to handle all element types and 1-d and 2-d cases
  - fixes to cgnscheck
  - cleaned up some compiler warnings
  - added cgnsBuild.defs Makefile include to installation
  - removed unneeded tools directory from cgnstools
  - cgnstools no longer built automatically - need to set configure flag
  - allow CellCenter for BCs
  - added cg_precision and cg_precision_f functions to get integer
    size used to create the file (32 or 64)
* Sun Oct 14 2012 scorot@free.fr
- enable legacy and fortran interface
* Sat Oct 13 2012 scorot@free.fr
- spec file reformating
- install shared librarie and put it in a separate package
- enable hdf5 support
- update to version 3.1.3
  * No changelog available
